@@ -44,16 +44,17 @@ use warnings;
 use Role::Tiny::With;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-06-17'; # DATE
+our $DATE = '2023-07-28'; # DATE
 our $DIST = 'TableData-Acme-CPANAuthors'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 with 'TableDataRole::Acme::CPANAuthors';
 
 # STATS
 
 1;
-# ABSTRACT: Authors listed in a Acme::CPANAuthors::* module
+# PODNAME: TableData::Acme::CPANAuthors
+# ABSTRACT: Authors listed in an Acme::CPANAuthors::* module
 
 __END__
 
@@ -63,11 +64,11 @@ __END__
 
 =head1 NAME
 
-TableDataRole::Acme::CPANAuthors - Authors listed in a Acme::CPANAuthors::* module
+TableData::Acme::CPANAuthors - Authors listed in an Acme::CPANAuthors::* module
 
 =head1 VERSION
 
-This document describes version 0.002 of TableDataRole::Acme::CPANAuthors (from Perl distribution TableData-Acme-CPANAuthors), released on 2023-06-17.
+This document describes version 0.003 of TableDataRole::Acme::CPANAuthors (from Perl distribution TableData-Acme-CPANAuthors), released on 2023-07-28.
 
 =head1 SYNOPSIS
 
